# Copyright 2019 The Lucid Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

import tensorflow as tf


def create_session(target='', timeout_sec=10):
  '''Create an intractive TensorFlow session.

  Helper function that creates TF session that uses growing GPU memory
  allocation and opration timeout. 'allow_growth' flag prevents TF
  from allocating the whole GPU memory an once, which is useful
  when having multiple python sessions sharing the same GPU.
  '''
  graph = tf.Graph()
  config = tf.compat.v1.ConfigProto()
  config.gpu_options.allow_growth = True
  config.operation_timeout_in_ms = int(timeout_sec*1000)
  return tf.compat.v1.InteractiveSession(target=target, graph=graph, config=config)
